@@ -1,7 +1,7 @@
 package Mooish::Caller::Util;
 
-our $DATE = '2015-07-27'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-07-30'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use warnings;
@@ -52,7 +52,8 @@ sub _get_constructor_caller_or_callers {
             }
 
             if ($is_build) {
-                if ($caller[0] eq 'Method::Generate::BuildAll') {
+                if ($caller[0] eq 'Method::Generate::BuildAll' ||
+                        $caller[0] eq 'Method::Generate::Constructor') {
                     $objsys = 'Moo';
                     next;
                 } elsif ($caller[0] eq 'Mo::build') {
@@ -100,7 +101,7 @@ sub _get_constructor_caller_or_callers {
                         $wrappers_done++;
                     } else { # Mouse
                         if ($] < 5.014) {
-                            next unless $skips++ >= 1;
+                            next if $skips++ < 1 && $caller[3] =~ /eval/;
                         }
                         $wrappers_done++;
                     }
@@ -113,7 +114,7 @@ sub _get_constructor_caller_or_callers {
                         $wrappers_done++;
                     } else { # Mouse
                         if ($] < 5.014) {
-                            next unless $skips++ >= 1;
+                            next if $skips++ < 1 && $caller[3] =~ /eval/;
                         }
                         $wrappers_done++;
                     }
@@ -159,7 +160,7 @@ Mooish::Caller::Util - Get constructor caller from inside Mo/Moo/Moose/Mouse's B
 
 =head1 VERSION
 
-This document describes version 0.05 of Mooish::Caller::Util (from Perl distribution Mooish-Caller-Util), released on 2015-07-27.
+This document describes version 0.06 of Mooish::Caller::Util (from Perl distribution Mooish-Caller-Util), released on 2015-07-30.
 
 =head1 SYNOPSIS
 
